@@ -1,5 +1,6 @@
 use async_trait::async_trait;
 use std::collections::HashMap;
+use tokio_tungstenite::tungstenite::Message;
 
 use crate::{
     clients::common_traits::{
@@ -84,8 +85,8 @@ impl MessageHandler for BithumbMessageHandler {
         }
     }
 
-    fn get_ping_msg_and_interval(&self) -> Option<(String, u64)> {
-        Some((r#"{"cmd":"ping"}"#.to_string(), 60))
+    fn get_ping_msg_and_interval(&self) -> Option<(Message, u64)> {
+        Some((Message::Text(r#"{"cmd":"ping"}"#.to_string()), 60))
     }
 }
 
